==> tcbj-center-reportapi-1.0.0-TCBJ-PROD-20240319.065744-8-sources.jar: com/dtyunxi/tcbj/api/dto/response/OrgRoleRespDto.java <==
package com.dtyunxi.tcbj.api.dto.response;

import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;

/**
 * @author jiejun
 * @date : 2022/02/22 10:56
 * @since 1.0.0
 */
@ApiModel(value = "组织角色返回对象")
public class OrgRoleRespDto {

    @ApiModelProperty(name = "id",value = "组织角色ID")
    private Long id;

    @ApiModelProperty(name = "name",value = "组织角色名称")
    private String name;

    @ApiModelProperty(name = "roleType",value = "组织角色类型 1：默认 2：普通")
    private Integer roleType;

    @ApiModelProperty(name = "status",value = "组织角色状态 1: 可用, 其他:不可用")
    private Integer status;

    @ApiModelProperty(name = "isEnableModify",value = "是否允许修改 1：允许")
    private Integer isEnableModify;

    @ApiModelProperty(name = "extension",value = "组织角色描述")
    private String extension;

    @ApiModelProperty(name = "instanceId",value = "系统应用ID")
    private Long instanceId;

    @ApiModelProperty(name = "appInsName",value = "系统应用名称")
    private String appInsName;

    @ApiModelProperty(name = "orgName",value = "组织名称")
    private String orgName;

    @ApiModelProperty(name = "orgCode",value = "组织代码")
    private String orgCode;

    @ApiModelProperty(name = "sellerName",value = "商家名称")
    private String sellerName;

    @ApiModelProperty(name = "parentSellerName",value = "上级商家名称")
    private String parentSellerName;

    @ApiModelProperty(name = "customerCode",value = "客户编号")
    private String customerCode;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public Integer getRoleType() {
        return roleType;
    }

    public void setRoleType(Integer roleType) {
        this.roleType = roleType;
    }

    public Integer getStatus() {
        return status;
    }

    public void setStatus(Integer status) {
        this.status = status;
    }

    public Integer getIsEnableModify() {
        return isEnableModify;
    }

    public void setIsEnableModify(Integer isEnableModify) {
        this.isEnableModify = isEnableModify;
    }

    public String getExtension() {
        return extension;
    }

    public void setExtension(String extension) {
        this.extension = extension;
    }

    public Long getInstanceId() {
        return instanceId;
    }

    public void setInstanceId(Long instanceId) {
        this.instanceId = instanceId;
    }

    public String getAppInsName() {
        return appInsName;
    }

    public void setAppInsName(String appInsName) {
        this.appInsName = appInsName;
    }

    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }

    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }

    public String getSellerName() {
        return sellerName;
    }

    public void setSellerName(String sellerName) {
        this.sellerName = sellerName;
    }

    public String getParentSellerName() {
        return parentSellerName;
    }

    public void setParentSellerName(String parentSellerName) {
        this.parentSellerName = parentSellerName;
    }

    public String getCustomerCode() {
        return customerCode;
    }

    public void setCustomerCode(String customerCode) {
        this.customerCode = customerCode;
    }
}

==> tcbj-center-reportapi-2.0.0-TCBJ-PROD-20251117.090219-79-sources.jar: com/dtyunxi/tcbj/api/dto/response/OrgRoleRespDto.java <==
package com.dtyunxi.tcbj.api.dto.response;

import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;

/**
 * @author jiejun
 * @date : 2022/02/22 10:56
 * @since 1.0.0
 */
@ApiModel(value = "组织角色返回对象")
public class OrgRoleRespDto {

    @ApiModelProperty(name = "id",value = "组织角色ID")
    private Long id;

    @ApiModelProperty(name = "name",value = "组织角色名称")
    private String name;

    @ApiModelProperty(name = "roleType",value = "组织角色类型 1：默认 2：普通")
    private Integer roleType;

    @ApiModelProperty(name = "status",value = "组织角色状态 1: 可用, 其他:不可用")
    private Integer status;

    @ApiModelProperty(name = "isEnableModify",value = "是否允许修改 1：允许")
    private Integer isEnableModify;

    @ApiModelProperty(name = "description",value = "组织角色描述")
    private String description;

    @ApiModelProperty(name = "instanceId",value = "系统应用ID")
    private Long instanceId;

    @ApiModelProperty(name = "appInsName",value = "系统应用名称")
    private String appInsName;

    @ApiModelProperty(name = "orgName",value = "组织名称")
    private String orgName;

    @ApiModelProperty(name = "orgCode",value = "组织代码")
    private String orgCode;

    @ApiModelProperty(name = "sellerName",value = "商家名称")
    private String sellerName;

    @ApiModelProperty(name = "parentSellerName",value = "上级商家名称")
    private String parentSellerName;

    @ApiModelProperty(name = "customerCode",value = "客户编号")
    private String customerCode;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public Integer getRoleType() {
        return roleType;
    }

    public void setRoleType(Integer roleType) {
        this.roleType = roleType;
    }

    public Integer getStatus() {
        return status;
    }

    public void setStatus(Integer status) {
        this.status = status;
    }

    public Integer getIsEnableModify() {
        return isEnableModify;
    }

    public void setIsEnableModify(Integer isEnableModify) {
        this.isEnableModify = isEnableModify;
    }

    public String getDescription() {
        return description;
    }

    public void setDescription(String description) {
        this.description = description;
    }

    public Long getInstanceId() {
        return instanceId;
    }

    public void setInstanceId(Long instanceId) {
        this.instanceId = instanceId;
    }

    public String getAppInsName() {
        return appInsName;
    }

    public void setAppInsName(String appInsName) {
        this.appInsName = appInsName;
    }

    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }

    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }

    public String getSellerName() {
        return sellerName;
    }

    public void setSellerName(String sellerName) {
        this.sellerName = sellerName;
    }

    public String getParentSellerName() {
        return parentSellerName;
    }

    public void setParentSellerName(String parentSellerName) {
        this.parentSellerName = parentSellerName;
    }

    public String getCustomerCode() {
        return customerCode;
    }

    public void setCustomerCode(String customerCode) {
        this.customerCode = customerCode;
    }
}
